@@ -15,7 +15,6 @@
 #include "diff.h"
 #include "lokalize_debug.h"
 #include "mergecatalog.h"
-#include "prefs_lokalize.h"
 #include "project.h"
 #include "projectbase.h"
 #include "tmview.h" // For the DynamicItemHeightQListWidget and other functionality
@@ -29,6 +28,7 @@
 #include <QStringBuilder>
 #include <QStringLiteral>
 #include <QToolTip>
+#include <QtAssert>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -36,14 +36,15 @@
 
 AltTransView::AltTransView(QWidget *parent, Catalog *catalog, const QVector<QAction *> &actions)
     : QDockWidget(i18nc("@title:window", "Alternate Translations"), parent)
-    , m_atm_entries_list(new TM::DynamicItemHeightQListWidget(this))
+    , m_entriesList(new TM::DynamicItemHeightQListWidget(this))
     , m_catalog(catalog)
     , m_normTitle(i18nc("@title:window", "Alternate Translations"))
     , m_hasInfoTitle(m_normTitle + QStringLiteral(" [*]"))
     , m_actions(actions)
 {
     setObjectName(QStringLiteral("msgIdDiff"));
-    setWidget(m_atm_entries_list);
+    setWidget(m_entriesList);
+    m_everCheckedAboutPromptingToShow = false;
     QTimer::singleShot(0, this, &AltTransView::initLater);
 }
 
@@ -51,10 +52,6 @@ void AltTransView::initLater()
 {
     setAcceptDrops(true);
 
-    KConfig config;
-    KConfigGroup group(&config, QStringLiteral("AltTransView"));
-    m_everShown = group.readEntry("EverShown", false);
-
     int i = m_actions.size();
     while (--i >= 0) {
         connect(m_actions.at(i), &QAction::triggered, this, [this, i] {
@@ -70,7 +67,7 @@ AltTransView::~AltTransView()
 void AltTransView::showEvent(QShowEvent *event)
 {
     if (event->type() == QShowEvent::Show)
-        m_atm_entries_list->updateListItemHeights();
+        m_entriesList->updateListItemHeights();
     QWidget::showEvent(event);
 }
 
@@ -131,7 +128,7 @@ void AltTransView::process()
     if (m_entry == m_prevEntry)
         return;
     if (m_catalog->numberOfEntries() <= m_entry.entry) {
-        m_atm_entries_list->clear();
+        m_entriesList->clear();
         return; // because of Qt::QueuedConnection
     }
 
@@ -145,36 +142,22 @@ void AltTransView::process()
             m_hasInfo = false;
             setWindowTitle(m_normTitle);
         }
-        m_atm_entries_list->clear();
+        m_entriesList->clear();
         return;
     }
     if (!m_hasInfo) {
         m_hasInfo = true;
         setWindowTitle(m_hasInfoTitle);
     }
-    if (!isVisible() && !Settings::altTransViewEverShownWithData()) {
-        if (KMessageBox::PrimaryAction
-            == KMessageBox::questionTwoActions(
-                this,
-                i18n("There is useful data available in Alternate Translations view.\n\n"
-                     "For Gettext PO files it displays difference between current source text "
-                     "and the source text corresponding to the fuzzy translation found by msgmerge when updating PO based on POT template.\n\n"
-                     "Do you want to show the view with the data?"),
-                i18nc("@title", "Alternative Translations Available"),
-                KGuiItem(i18nc("@action", "Show Data View")),
-                KStandardGuiItem::cancel())) {
-            show();
-        }
 
-        Settings::setAltTransViewEverShownWithData(true);
-    }
+    conditionallyPromptToDisplay();
 
     CatalogString source = m_catalog->sourceWithTags(m_entry.toDocPosition());
     QString context = m_catalog->context(m_entry.toDocPosition()).first();
 
     setUpdatesEnabled(false);
-    m_atm_entries_list->viewport()->setUpdatesEnabled(false);
-    m_atm_entries_list->clear();
+    m_entriesList->viewport()->setUpdatesEnabled(false);
+    m_entriesList->clear();
     int i = 0;
     int limit = entries.size();
     QString translationDetails = i18n("From alternate translations folder");
@@ -200,7 +183,7 @@ void AltTransView::process()
                 // characters used in the messages.)
                 prevMsgCtxt.replace(QStringLiteral("\n"), QString());
                 currentMsgCtxt.replace(QStringLiteral("\n"), QString());
-                QString contextHeader = i18nc("Title for an alternative translation entry context diff.", "Comparison with previous context:");
+                QString contextHeader = i18nc("Title for an alternate translation entry context diff.", "Comparison with previous context:");
                 contextString = QStringLiteral("<strong>%1</strong><br>%2<br>")
                                     .arg(contextHeader,
                                          userVisibleWordDiff(prevMsgCtxt, currentMsgCtxt, Project::instance()->accel(), Project::instance()->markup(), Html));
@@ -215,7 +198,7 @@ void AltTransView::process()
                 // characters used in the messages.)
                 prevMsgId.replace(QStringLiteral("\n"), QString());
                 currentMsgId.replace(QStringLiteral("\n"), QString());
-                QString sourceHeader = i18nc("Title for alternative translation source diff.", "Comparison with previous source:");
+                QString sourceHeader = i18nc("Title for alternate translation source diff.", "Comparison with previous source:");
                 sourceString =
                     QStringLiteral("<strong>%1</strong><br>%2<br>")
                         .arg(sourceHeader, userVisibleWordDiff(prevMsgId, currentMsgId, Project::instance()->accel(), Project::instance()->markup(), Html));
@@ -225,7 +208,7 @@ void AltTransView::process()
             sourceString.clear();
         }
         // Here we are working with different data to the context and id above:
-        // an example of the translation into an alternative language. As such,
+        // an example of the translation into an alternate language. As such,
         // display a translation entry like those in the Translation Memory.
         if (!entry.target.isEmpty()) {
             m_actions.at(i)->setStatusTip(entry.target.string);
@@ -244,8 +227,8 @@ void AltTransView::process()
         QListWidgetItem *translationMemoryEntryItem = new QListWidgetItem();
         TM::DoubleClickToInsertTextQLabel *label =
             new TM::DoubleClickToInsertTextQLabel(QStringLiteral("%1%2%3%4").arg(metadata, contextString, targetString, sourceString));
-        m_atm_entries_list->addItem(translationMemoryEntryItem);
-        m_atm_entries_list->setItemWidget(translationMemoryEntryItem, label);
+        m_entriesList->addItem(translationMemoryEntryItem);
+        m_entriesList->setItemWidget(translationMemoryEntryItem, label);
 
         // Double-clicking words in a TM entry should add the selected
         // word to the current translation target at the cursor position.
@@ -255,27 +238,44 @@ void AltTransView::process()
             break;
     }
 
-    if (!m_everShown) {
-        m_everShown = true;
-        show();
-
-        KConfig config;
-        KConfigGroup group(&config, QStringLiteral("AltTransView"));
-        group.writeEntry("EverShown", true);
-    }
-
-    m_atm_entries_list->updateListItemHeights();
-    m_atm_entries_list->viewport()->setUpdatesEnabled(true);
+    m_entriesList->updateListItemHeights();
+    m_entriesList->viewport()->setUpdatesEnabled(true);
     setUpdatesEnabled(true);
 }
 
+void AltTransView::conditionallyPromptToDisplay()
+{
+    if (m_everCheckedAboutPromptingToShow)
+        return;
+    m_everCheckedAboutPromptingToShow = true;
+
+    Q_ASSERT(!m_catalog->altTrans(m_entry.toDocPosition()).isEmpty());
+
+    // The prompt will not show if the user has ticked "Do not show again". In this case whatever
+    // choice the user made at that time will be used i.e. can always show if data is available.
+    if (!isVisible()
+        && KMessageBox::PrimaryAction
+            == KMessageBox::questionTwoActions(this,
+                                               i18n("There is useful data available in Alternate Translations view.\n\n"
+                                                    "For Gettext PO files it displays difference between current source "
+                                                    "text and the source text corresponding to the fuzzy translation "
+                                                    "found by msgmerge when updating PO based on POT template.\n\n"
+                                                    "Do you want to show the view with the data?"),
+                                               i18nc("@title", "Alternative Translations Available"),
+                                               KGuiItem(i18nc("@action", "Show Data View")),
+                                               KStandardGuiItem::cancel(),
+                                               QStringLiteral("ResponseToShowAlternateTranslationsViewDialogWhenDataPresent"))) {
+        show();
+    }
+}
+
 bool AltTransView::event(QEvent *event)
 {
     if (event->type() == QEvent::ToolTip) {
         QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
 
-        for (int i = 0; i < m_atm_entries_list->count(); ++i) {
-            if (m_atm_entries_list->itemWidget(m_atm_entries_list->item(i))->underMouse()) {
+        for (int i = 0; i < m_entriesList->count(); ++i) {
+            if (m_entriesList->itemWidget(m_entriesList->item(i))->underMouse()) {
                 if (i >= m_entries.size())
                     return false;
                 QString origin = m_entries.at(i).origin;
@@ -298,8 +298,8 @@ bool AltTransView::event(QEvent *event)
                                 "toolview to use it as a source for additional alternate translations.");
         QToolTip::showText(helpEvent->globalPos(), tooltip);
         return true;
-    } else if (event->type() == QEvent::Resize && m_atm_entries_list->count() > 0) {
-        m_atm_entries_list->updateListItemHeights();
+    } else if (event->type() == QEvent::Resize && m_entriesList->count() > 0) {
+        m_entriesList->updateListItemHeights();
     }
     return QDockWidget::event(event);
 }
@@ -326,11 +326,9 @@ void AltTransView::slotUseSuggestion(int i)
     if (!old.isEmpty()) {
         // FIXME test!
         removeTargetSubstring(m_catalog, m_entry.toDocPosition(), 0, old.size());
-        // m_catalog->push(new DelTextCmd(m_catalog,m_pos,m_catalog->msgstr(m_pos)));
     }
     qCWarning(LOKALIZE_LOG) << "1" << target.string;
 
-    // m_catalog->push(new InsTextCmd(m_catalog,m_pos,target)/*,true*/);
     insertCatalogString(m_catalog, m_entry.toDocPosition(), target, 0);
 
     m_catalog->endMacro();
