@@ -7,24 +7,23 @@
   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
-
 #ifndef QAVIEW_H
 #define QAVIEW_H
 
 #include <QDockWidget>
-#include <QTreeView>
 #include <QDomDocument>
+#include <QTreeView>
 
 #include "rule.h"
 
 class QaModel;
 
-class QaView: public QDockWidget
+class QaView : public QDockWidget
 {
     Q_OBJECT
 
 public:
-    explicit QaView(QWidget*);
+    explicit QaView(QWidget *);
     ~QaView();
 
     bool loadRules(QString filename = QString());
@@ -39,16 +38,13 @@ Q_SIGNALS:
     void rulesChanged();
 
 private:
-    QTreeView* m_browser{};
-    QaModel* m_qaModel{};
+    QTreeView *const m_browser;
+    QaModel *m_qaModel{};
     QString m_filename;
 
     QVector<Rule> m_rules;
 };
 
-int findMatchingRule(const QVector<Rule>& rules, const QString& source, const QString& target,
-                     QVector<StartLen>& positions);
+int findMatchingRule(const QVector<Rule> &rules, const QString &source, const QString &target, QVector<StartLen> &positions);
 
 #endif // QAVIEW_H
-
-
